@@ -134,7 +134,7 @@ where
             }
         }
 
-        log::debug!("sequences: Compressing statements as a sequences");
+        tracing::debug!("sequences: Compressing statements as a sequences");
 
         self.changed = true;
         let mut exprs = vec![];
@@ -414,7 +414,9 @@ where
             }
         }
         self.changed = true;
-        log::debug!("sequences: Splitted a sequence exprssion to multiple expression statements");
+        tracing::debug!(
+            "sequences: Splitted a sequence exprssion to multiple expression statements"
+        );
         *stmts = new_stmts;
     }
 
@@ -448,7 +450,7 @@ where
             if !can_work {
                 return;
             }
-            log::debug!("sequences: Lifting");
+            tracing::debug!("sequences: Lifting");
             self.changed = true;
         }
 
@@ -522,7 +524,7 @@ where
                                     continue;
                                 }
                                 self.changed = true;
-                                log::debug!("sequences: Hoisting `var` without init");
+                                tracing::debug!("sequences: Hoisting `var` without init");
                                 let s = Stmt::Decl(Decl::Var(VarDecl {
                                     span: v.span,
                                     kind: VarDeclKind::Var,
@@ -567,7 +569,7 @@ where
                         if lhs.sym == last_id.sym && lhs.span.ctxt == last_id.span.ctxt {
                             e.exprs.pop();
                             self.changed = true;
-                            log::debug!("sequences: Shifting assignment");
+                            tracing::debug!("sequences: Shifting assignment");
                             return;
                         }
                     };
@@ -592,7 +594,7 @@ where
         if let Some(last) = e.exprs.last() {
             if is_pure_undefined(&last) {
                 self.changed = true;
-                log::debug!("sequences: Shifting void");
+                tracing::debug!("sequences: Shifting void");
 
                 e.exprs.pop();
                 let last = e.exprs.last_mut().unwrap();
@@ -637,14 +639,14 @@ where
 
         if !self.options.sequences() && !self.options.collapse_vars {
             if cfg!(feature = "debug") {
-                log::trace!("sequences: [x] Disabled");
+                tracing::trace!("sequences: [x] Disabled");
             }
             return;
         }
 
         if self.ctx.in_top_level() && !self.options.top_level() {
             if cfg!(feature = "debug") {
-                log::trace!("sequences: [x] Top level");
+                tracing::trace!("sequences: [x] Top level");
             }
             return;
         }
@@ -677,7 +679,7 @@ where
         exprs.push(buf);
 
         if cfg!(feature = "debug") {
-            log::trace!(
+            tracing::trace!(
                 "sequences: Merging statements: {:?}",
                 exprs.iter().map(|v| v.len()).collect::<Vec<_>>()
             );
@@ -780,7 +782,7 @@ where
                     Mergable::Expr(e2) => {
                         if !self.is_skippable_for_seq(Some(a), &*e2) {
                             if cfg!(feature = "debug") && false {
-                                log::trace!("Cannot skip: {}", dump(&**e2));
+                                tracing::trace!("Cannot skip: {}", dump(&**e2));
                             }
 
                             break;
@@ -922,19 +924,19 @@ where
             Expr::Update(..) => return false,
 
             Expr::Cond(b) => {
-                log::trace!("seq: Try test of cond");
+                tracing::trace!("seq: Try test of cond");
                 return self.merge_sequential_expr(a, &mut *b.test);
             }
 
             Expr::Unary(b) => {
-                log::trace!("seq: Try arg of unary");
+                tracing::trace!("seq: Try arg of unary");
                 return self.merge_sequential_expr(a, &mut b.arg);
             }
 
             Expr::Bin(BinExpr {
                 op, left, right, ..
             }) => {
-                log::trace!("seq: Try left of bin");
+                tracing::trace!("seq: Try left of bin");
                 if self.merge_sequential_expr(a, &mut **left) {
                     return true;
                 }
@@ -948,7 +950,7 @@ where
                     _ => {}
                 }
 
-                log::trace!("seq: Try right of bin");
+                tracing::trace!("seq: Try right of bin");
                 return self.merge_sequential_expr(a, &mut **right);
             }
 
@@ -957,7 +959,7 @@ where
                 computed: false,
                 ..
             }) => {
-                log::trace!("seq: Try object of member");
+                tracing::trace!("seq: Try object of member");
                 return self.merge_sequential_expr(a, &mut **obj);
             }
 
@@ -967,7 +969,7 @@ where
                 computed: true,
                 ..
             }) => {
-                log::trace!("seq: Try object of member (computed)");
+                tracing::trace!("seq: Try object of member (computed)");
                 if self.merge_sequential_expr(a, &mut **obj) {
                     return true;
                 }
@@ -976,14 +978,14 @@ where
                     return false;
                 }
 
-                log::trace!("seq: Try prop of member (computed)");
+                tracing::trace!("seq: Try prop of member (computed)");
                 return self.merge_sequential_expr(a, &mut **prop);
             }
 
             Expr::Assign(b @ AssignExpr { op: op!("="), .. }) => {
                 match &mut b.left {
                     PatOrExpr::Expr(b) => {
-                        log::trace!("seq: Try lhs of assign");
+                        tracing::trace!("seq: Try lhs of assign");
                         if self.merge_sequential_expr(a, &mut **b) {
                             return true;
                         }
@@ -998,7 +1000,7 @@ where
                     }
                     PatOrExpr::Pat(b) => match &mut **b {
                         Pat::Expr(b) => {
-                            log::trace!("seq: Try lhs of assign");
+                            tracing::trace!("seq: Try lhs of assign");
                             if self.merge_sequential_expr(a, &mut **b) {
                                 return true;
                             }
@@ -1015,7 +1017,7 @@ where
                     },
                 }
 
-                log::trace!("seq: Try rhs of assign");
+                tracing::trace!("seq: Try rhs of assign");
                 return self.merge_sequential_expr(a, &mut b.right);
             }
 
@@ -1040,7 +1042,7 @@ where
                     },
                 }
 
-                log::trace!("seq: Try rhs of assign with op");
+                tracing::trace!("seq: Try rhs of assign with op");
                 return self.merge_sequential_expr(a, &mut b.right);
             }
 
@@ -1048,7 +1050,7 @@ where
                 for elem in &mut b.elems {
                     match elem {
                         Some(elem) => {
-                            log::trace!("seq: Try element of array");
+                            tracing::trace!("seq: Try element of array");
                             if self.merge_sequential_expr(a, &mut elem.expr) {
                                 return true;
                             }
@@ -1074,7 +1076,7 @@ where
                 ..
             }) => {
                 let is_this_undefined = b_callee.is_ident();
-                log::trace!("seq: Try callee of call");
+                tracing::trace!("seq: Try callee of call");
                 if self.merge_sequential_expr(a, &mut **b_callee) {
                     if is_this_undefined {
                         match &**b_callee {
@@ -1083,7 +1085,7 @@ where
                                     span: DUMMY_SP,
                                     value: 0.0,
                                 })));
-                                log::trace!("injecting zero to preserve `this` in call");
+                                tracing::trace!("injecting zero to preserve `this` in call");
 
                                 *b_callee = Box::new(Expr::Seq(SeqExpr {
                                     span: b_callee.span(),
@@ -1103,7 +1105,7 @@ where
                 }
 
                 for arg in b_args {
-                    log::trace!("seq: Try arg of call");
+                    tracing::trace!("seq: Try arg of call");
                     if self.merge_sequential_expr(a, &mut arg.expr) {
                         return true;
                     }
@@ -1119,7 +1121,7 @@ where
             Expr::New(NewExpr {
                 callee: b_callee, ..
             }) => {
-                log::trace!("seq: Try callee of new");
+                tracing::trace!("seq: Try callee of new");
                 if self.merge_sequential_expr(a, &mut **b_callee) {
                     return true;
                 }
@@ -1129,7 +1131,7 @@ where
 
             Expr::Seq(SeqExpr { exprs: b_exprs, .. }) => {
                 for b_expr in b_exprs {
-                    log::trace!("seq: Try elem of seq");
+                    tracing::trace!("seq: Try elem of seq");
 
                     if self.merge_sequential_expr(a, &mut **b_expr) {
                         return true;
@@ -1206,7 +1208,7 @@ where
         }
 
         // if cfg!(feature = "debug") && false {
-        //     log::trace!(
+        //     tracing::trace!(
         //         "sequences: Trying to merge `{}` => `{}`",
         //         dump(&*a),
         //         dump(&*b)
@@ -1243,7 +1245,7 @@ where
                                 };
                                 b.visit_with(&Invalid { span: DUMMY_SP }, &mut v);
                                 if v.expr_usage != 1 || v.pat_usage != 0 {
-                                    log::trace!(
+                                    tracing::trace!(
                                         "[X] sequences: Aborting merging of an update expression \
                                          because of usage counts ({}, ref = {}, pat = {})",
                                         a_id,
@@ -1294,7 +1296,7 @@ where
                         let left_id = match get_lhs_ident(left) {
                             Some(v) => v,
                             None => {
-                                log::trace!("[X] sequences: Aborting because lhs is not an id");
+                                tracing::trace!("[X] sequences: Aborting because lhs is not an id");
                                 return false;
                             }
                         };
@@ -1305,7 +1307,7 @@ where
                             .and_then(|data| data.vars.get(&left_id.to_id()))
                         {
                             if usage.declared_as_fn_expr {
-                                log::trace!(
+                                tracing::trace!(
                                     "sequences: [X] Declared as fn expr ({}, {:?})",
                                     left_id.sym,
                                     left_id.span.ctxt
@@ -1387,7 +1389,7 @@ where
                 }
 
                 if used_by_b.contains(id) {
-                    log::trace!("[X] sequences: Aborting because of deps");
+                    tracing::trace!("[X] sequences: Aborting because of deps");
                     return false;
                 }
             }
@@ -1402,7 +1404,7 @@ where
             };
             b.visit_with(&Invalid { span: DUMMY_SP }, &mut v);
             if v.expr_usage != 1 || v.pat_usage != 0 {
-                log::trace!(
+                tracing::trace!(
                     "[X] sequences: Aborting because of usage counts ({}{:?}, ref = {}, pat = {})",
                     left_id.sym,
                     left_id.span.ctxt,
@@ -1414,7 +1416,7 @@ where
         }
 
         self.changed = true;
-        log::debug!(
+        tracing::debug!(
             "sequences: Inlining sequential expressions (`{}{:?}`)",
             left_id.sym,
             left_id.span.ctxt
